function check_file_exists() {
  local file=$1
  [[ -f $(readlink -m ${file}) ]] || exit_with NOT_APPLICABLE
  head -n1 ${file} > /dev/null || exit_with ERROR
}

function iniget {
  local file=$1
  local section=$2
  local option=$3
  local line
  line=$(sed -ne "/^\[$section\]/,/^\[.*\]/ { /^$option[ \t]*=/ p; }" "$file")
  echo ${line#*=}
}

function inicheck {
  local file=$1
  local section=$2
  local option=$3
  local pattern=$4
  local test_value=$5
  local value
  local line
  check_file_exists ${file}
  value=$(iniget ${file} ${section} ${option})
  if [[ ${value} == '' ]]; then
    if [[ ${test_value} != '' ]]; then
      exit_with FAIL
    else
      exit_with UNKNOWN
    fi
  fi
  [[ `eval ${value} ${pattern} ${test_value}` ]] || exit_with FAIL
}

function perms_le() {
  local perms=${1}
  local file=${2}
  check_file_exists ${file}
  local fperms=$(stat -L -c "%a" ${file})
  [[ ${fperms:0:1} -le ${perms:0:1} ]] && \
  [[ ${fperms:1:1} -le ${perms:1:1} ]] && \
  [[ ${fperms:2:1} -le ${perms:2:1} ]] || exit_with FAIL
}

function check_user_group() {
  local file=${1}
  local user=${2}
  local group=${3}
  check_file_exists ${file}
  stat -L -c "%U %G" ${file} | egrep "${user} ${group}" || exit_with FAIL
}

function check_dashboard_setting_value() {
  local key=$1
  local value=$2
  local file=${3:-/etc/openstack-dashboard/local_settings.py}
  check_file_exists ${file}
  val=$(awk -F'=' "/^${key}/ {print \$2}" ${file})
  [[ x${val} == x"${value}" ]] || exit_with FAIL
}
